==> Bio-Phylo-0.16.tar.gz: Bio-Phylo-0.16/lib/Bio/Phylo/Matrices/Datatype/Protein.pm <==
package Bio::Phylo::Matrices::Datatype::Protein;
use strict;
use vars qw($LOOKUP @ISA $MISSING $GAP);
@ISA = qw(Bio::Phylo::Matrices::Datatype);

=head1 NAME

Bio::Phylo::Matrices::Datatype::Protein - Datatype subclass,
no serviceable parts inside

=head1 DESCRIPTION

The Bio::Phylo::Matrices::Datatype::* classes are used to validated data
contained by L<Bio::Phylo::Matrices::Matrix> and L<Bio::Phylo::Matrices::Datum>
objects.

=head1 SEE ALSO

=over

=item L<Bio::Phylo::Matrices::Datatype>

This class subclasses L<Bio::Phylo::Matrices::Datatype>.

=item L<Bio::Phylo::Manual>

Also see the manual: L<Bio::Phylo::Manual>.

=back

=head1 FORUM

CPAN hosts a discussion forum for Bio::Phylo. If you have trouble
using this module the discussion forum is a good place to start
posting questions (NOT bug reports, see below):
L<http://www.cpanforum.com/dist/Bio-Phylo>

=head1 BUGS

Please report any bugs or feature requests to C<< bug-bio-phylo@rt.cpan.org >>,
or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Bio-Phylo>. I will be notified,
and then you'll automatically be notified of progress on your bug as I make
changes. Be sure to include the following in your request or comment, so that
I know what version you're using:

$Id: Protein.pm 3386 2007-03-24 16:22:25Z rvosa $

=head1 AUTHOR

Rutger Vos,

=over

=item email: C<< rvosa@sfu.ca >>

=item web page: L<http://www.sfu.ca/~rvosa/>

=back

=head1 ACKNOWLEDGEMENTS

The author would like to thank Jason Stajich for many ideas borrowed
from BioPerl L<http://www.bioperl.org>, and CIPRES
L<http://www.phylo.org> and FAB* L<http://www.sfu.ca/~fabstar>
for comments and requests.

=head1 COPYRIGHT & LICENSE

Copyright 2005 Rutger Vos, All Rights Reserved.
This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut

$LOOKUP = {
    'A' => [ 'A'      ],
    'B' => [ 'D', 'N' ],
    'C' => [ 'C'      ],
    'D' => [ 'D'      ],
    'E' => [ 'E'      ],
    'F' => [ 'F'      ],
    'G' => [ 'G'      ],
    'H' => [ 'H'      ],
    'I' => [ 'I'      ],
    'K' => [ 'K'      ],
    'L' => [ 'L'      ],
    'M' => [ 'M'      ],
    'N' => [ 'N'      ],
    'P' => [ 'P'      ],
    'Q' => [ 'Q'      ],
    'R' => [ 'R'      ],
    'S' => [ 'S'      ],
    'T' => [ 'T'      ],
    'U' => [ 'U'      ],
    'V' => [ 'V'      ],
    'W' => [ 'W'      ],
    'X' => [ 'X'      ],
    'Y' => [ 'Y'      ],
    'Z' => [ 'E', 'Q' ],
    '*' => [ '*'      ],
};

$MISSING = '?';

$GAP = '-';
            
1;

==> Bio-Phylo-0.18.tar.gz: Bio-Phylo-0.18/lib/Bio/Phylo/Matrices/Datatype/Protein.pm <==
# $Id: Protein.pm 844 2009-03-05 00:07:26Z rvos $
package Bio::Phylo::Matrices::Datatype::Protein;
use Bio::Phylo::Matrices::Datatype;
use strict;
use vars qw($LOOKUP @ISA $MISSING $GAP);
@ISA = qw(Bio::Phylo::Matrices::Datatype);

=head1 NAME

Bio::Phylo::Matrices::Datatype::Protein - Validator subclass,
no serviceable parts inside

=head1 DESCRIPTION

The Bio::Phylo::Matrices::Datatype::* classes are used to validate data
contained by L<Bio::Phylo::Matrices::Matrix> and L<Bio::Phylo::Matrices::Datum>
objects.

=cut

# podinherit_insert_token

=head1 SEE ALSO

=over

=item L<Bio::Phylo::Matrices::Datatype>

This class subclasses L<Bio::Phylo::Matrices::Datatype>.

=item L<Bio::Phylo::Manual>

Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.

=back

=head1 FORUM

CPAN hosts a discussion forum for Bio::Phylo. If you have trouble
using this module the discussion forum is a good place to start
posting questions (NOT bug reports, see below):
L<http://www.cpanforum.com/dist/Bio-Phylo>

=head1 REVISION

 $Id: Protein.pm 844 2009-03-05 00:07:26Z rvos $

=cut

$LOOKUP = {
    'A' => [ 'A'      ],
    'B' => [ 'D', 'N' ],
    'C' => [ 'C'      ],
    'D' => [ 'D'      ],
    'E' => [ 'E'      ],
    'F' => [ 'F'      ],
    'G' => [ 'G'      ],
    'H' => [ 'H'      ],
    'I' => [ 'I'      ],
    'K' => [ 'K'      ],
    'L' => [ 'L'      ],
    'M' => [ 'M'      ],
    'N' => [ 'N'      ],
    'P' => [ 'P'      ],
    'Q' => [ 'Q'      ],
    'R' => [ 'R'      ],
    'S' => [ 'S'      ],
    'T' => [ 'T'      ],
    'U' => [ 'U'      ],
    'V' => [ 'V'      ],
    'W' => [ 'W'      ],
    'X' => [ 'X'      ],
    'Y' => [ 'Y'      ],
    'Z' => [ 'E', 'Q' ],
    '*' => [ '*'      ],
};

$MISSING = '?';

$GAP = '-';
            
1;
